:mod:`trac.loader`
==================

.. automodule :: trac.loader
   :members:

.. autofunction :: get_plugin_info
.. autofunction :: load_eggs
.. autofunction :: load_py_files
.. autofunction :: match_plugins_to_frames

